#
# spec file for package ceph-iscsi
#
# Copyright (C) 2017-2018 The Ceph iSCSI Project Developers. See
# COPYING file at the top-level directory of this distribution and at
# https://github.com/ceph/ceph-iscsi/blob/master/COPYING
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon.
#
# This file is under the GNU General Public License, version 3 or any
# later version.
#
# Please submit bugfixes or comments via http://tracker.ceph.com/
#
%if 0%{?rhel} == 7
%global with_python2 1
%endif


Name:           ceph-iscsi
Version:        3.0+1553528639.g1149ac6
Release:        1.1
Group:          System/Filesystems
Summary:        Python modules for Ceph iSCSI gateway configuration management
%if 0%{?suse_version}
License:        GPL-3.0-or-later
%else
License:        GPLv3+
%endif
URL:            https://github.com/ceph/ceph-iscsi
Source0:        %{name}-%{version}.tar.gz
%if 0%{?suse_version}
Source98:       checkin.sh
Source99:       README-checkin.txt
%endif

BuildArch:      noarch

Obsoletes:      ceph-iscsi-config
Obsoletes:      ceph-iscsi-cli

%if 0%{?with_python2}
BuildRequires:  python2-devel
BuildRequires:  python2-setuptools
Requires:       python-rados >= 10.2.2
Requires:       python-rbd >= 10.2.2
Requires:       python-netifaces >= 0.10.4
Requires:       python-rtslib >= 2.1.fb67
Requires:       rpm-python >= 4.11
Requires:       python-cryptography
Requires:       python-flask >= 0.10.1
Requires:       python-configshell
%else
BuildRequires:  python3-devel
BuildRequires:  python3-setuptools
Requires:       python3-rados >= 10.2.2
Requires:       python3-rbd >= 10.2.2
Requires:       python3-netifaces >= 0.10.4
Requires:       python3-rtslib >= 2.1.fb67
Requires:       python3-cryptography
Requires:       python3-rpm >= 4.11
%if 0%{?suse_version}
BuildRequires:  python-rpm-macros
BuildRequires:  fdupes
Requires:       python3-Flask >= 0.10.1
Requires:       python3-configshell-fb
%else
Requires:       python3-flask >= 0.10.1
Requires:       python3-configshell
%endif
%endif

BuildRequires:  systemd

%description
Python package providing the modules used to handle the configuration of an
iSCSI gateway, backed by Ceph RBD. The RPM installs configuration management
logic (ceph_iscsi_config modules), an rbd-target-gw systemd service, and
a CLI-based management tool 'gwcli', replacing the 'targetcli' tool.

The configuration management modules may be are consumed by custom Ansible
playbooks and the rbd-target-gw daemon.

The rbd-target-gw service is responsible for startup and shutdown actions,
replacing the 'target' service used in standalone LIO implementations.
In addition, rbd-target-gw also provides a REST API utilized by the Ceph
dashboard and gwcli tool, and a prometheus exporter for gateway LIO
performance statistics, supporting monitoring and visualisation tools like
Grafana.

%prep
%autosetup -p1

%build
%if 0%{?with_python2}
%{__python2} setup.py build
%else
%if 0%{?suse_version}
%python3_build
%else
%{py3_build}
%endif
%endif

%install
%if 0%{?with_python2}
%{__python2} setup.py install -O1 --skip-build --root %{buildroot}  --install-scripts %{_bindir}
%else
%if 0%{?suse_version}
%python3_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}
%else
%{py3_install}
%endif
%endif
mkdir -p %{buildroot}%{_unitdir}
install -m 0644 .%{_unitdir}/rbd-target-gw.service %{buildroot}%{_unitdir}
install -m 0644 .%{_unitdir}/rbd-target-api.service %{buildroot}%{_unitdir}
mkdir -p %{buildroot}%{_mandir}/man8
install -m 0644 gwcli.8 %{buildroot}%{_mandir}/man8/
gzip %{buildroot}%{_mandir}/man8/gwcli.8
mkdir -p %{buildroot}%{_unitdir}/rbd-target-gw.service.d
install -m 0644 .%{_sysconfdir}/systemd/system/rbd-target-gw.service.d/dependencies.conf %{buildroot}%{_unitdir}/rbd-target-gw.service.d/
%if 0%{?suse_version}
mkdir -p %{buildroot}%{_sbindir}
ln -s service %{buildroot}%{_sbindir}/rcrbd-target-gw
ln -s service %{buildroot}%{_sbindir}/rcrbd-target-api
%endif

%pre
%if 0%{?suse_version}
%service_add_pre rbd-target-gw.service rbd-target-api.service
%endif

%post
%if 0%{?fedora} || 0%{?rhel}
/bin/systemctl --system daemon-reload &> /dev/null || :
/bin/systemctl --system enable rbd-target-gw &> /dev/null || :
/bin/systemctl --system enable rbd-target-api &> /dev/null || :
%endif
%if 0%{?suse_version}
%service_add_post rbd-target-gw.service rbd-target-api.service
%endif

%preun
%if 0%{?suse_version}
%service_del_preun rbd-target-gw.service rbd-target-api.service
%endif

%postun
%if 0%{?fedora} || 0%{?rhel}
/bin/systemctl --system daemon-reload &> /dev/null || :
%endif
%if 0%{?suse_version}
%service_del_postun rbd-target-gw.service rbd-target-api.service
%endif


%files
%license LICENSE
%license COPYING
%doc README
%doc iscsi-gateway.cfg_sample
%if 0%{?with_python2}
%{python2_sitelib}/*
%else
%{python3_sitelib}/*
%endif
%{_bindir}/gwcli
%{_bindir}/rbd-target-gw
%{_bindir}/rbd-target-api
%{_unitdir}/rbd-target-gw.service
%{_unitdir}/rbd-target-api.service
%{_mandir}/man8/gwcli.8.gz
%attr(0770,root,root) %dir %{_localstatedir}/log/rbd-target-gw
%attr(0770,root,root) %dir %{_localstatedir}/log/rbd-target-api
%dir %{_unitdir}/rbd-target-gw.service.d
%{_unitdir}/rbd-target-gw.service.d/dependencies.conf
%if 0%{?suse_version}
%{_sbindir}/rcrbd-target-gw
%{_sbindir}/rcrbd-target-api
%endif

%changelog
* Mon Mar 25 2019 ncutler@suse.com
- Update to 3.0+1553528639.g1149ac6:
  + '/settings' endpoint return required and support RBD features by backstore
  + Enable/disable 'demo_mode_write_protect' when enabling/disabling ACL authentication
* Wed Mar 20 2019 ncutler@suse.com
- Update to 3.0+1553076762.g61c150a:
  + Gateway management fixes and features
  + regression: fix lun reconfigure failure
* Fri Mar 15 2019 ncutler@suse.com
- Update to 3.0+1552644320.g118bce3:
  + Fix chap config update
  + Always use rados client name when connecting to Ceph cluster
  + spec: add python-configshell runtime dependency
  + gw: use client id when calling ceph shell command
  + Fix race condition after gateway creation
  + Misc target/acl reconfigure fixes
* Mon Mar 11 2019 ncutler@suse.com
- Update to 3.0+1552304123.g67b0d30:
  + add support for 'rbd' backstore (Ricardo Marques)
* Thu Feb 28 2019 ncutler@suse.com
- Update to 3.0+1551350485.g157b5fd:
  + refactor spec file for better Fedora/RHEL and Python 3 support (Ricardo Dias)
  + rados pool for storing configuration is now configurable (Ricardo Marques)
  + support for specifying the cluster client name (Ricardo Dias)
* Tue Feb 19 2019 ncutler@suse.com
- Update to 3.0+1550592273.gda1fd9b:
  + Support for kernel LIO backstore (which is the default backstore on SES6)
    (Ricardo Marques)
  + Disable OS, and package version checks (Ricardo Marques)
* Thu Feb  7 2019 ncutler@suse.com
- checkin.sh: append git SHA1 to version number
* Mon Feb  4 2019 ncutler@suse.com
- Update to 3.0+1549277704:
  + based on upstream master SHA1 17023339c03f8a8ad289db7689f6d6424c2b860f
  * packaging: Move python unbuffered option to systemd unit file
    (bsc#1123070)
* Thu Jan 17 2019 ncutler@suse.com
- checkin.sh: ensure tarballs are uniquely named
* Wed Jan 16 2019 ncutler@suse.com
- multiple iSCSI target support (Ricardo Marques)
* Fri Dec  7 2018 ncutler@suse.com
- migrate from python3-pycrypto to python3-cryptography
  (Ricardo Dias)
* Wed Dec  5 2018 ncutler@suse.com
- spec: use correct package name for python3-Flask dependency
* Mon Nov 19 2018 ncutler@suse.com
- Add support for Python3 (Ricardo Marques)
* Wed Nov 14 2018 ncutler@suse.com
- Initial commit, based on SUSE/ceph-iscsi.git branch "ses6",
  SHA1 9c04ed0c3fe7a9ad057b3bb676f5f07cf97270fc
  (upstream 0b9046105d900ca03249d044ce759c12efa5a016)
